@@ -301,11 +301,11 @@ def sense_dynamic_circuit(params, task, action, message):
     # Provision dynamic circuit with sense-o
     if 'provision' in task:
         cmd = os.popen(str('sh noted/sense-o/sense-provision.sh ' + class_transfer_broker_.get_sense_uuid()   + ' ' + class_transfer_broker_.get_sense_vlan()));
-        cmd = os.popen(str('sh noted/sense-o/sense-provision.sh ' + class_transfer_broker_.get_sense_uuid_2() + ' ' + class_transfer_broker_.get_sense_vlan_2()));
+        if class_transfer_broker_.get_num_circuits == 2: cmd = os.popen(str('sh noted/sense-o/sense-provision.sh ' + class_transfer_broker_.get_sense_uuid_2() + ' ' + class_transfer_broker_.get_sense_vlan_2()));
     # Cancel dynamic circuit with sense-o
     else:
         cmd = os.popen(str('sh noted/sense-o/sense-cancel.sh ' + class_transfer_broker_.get_sense_uuid()   + ' ' + class_transfer_broker_.get_sense_vlan()));
-        cmd = os.popen(str('sh noted/sense-o/sense-cancel.sh ' + class_transfer_broker_.get_sense_uuid_2() + ' ' + class_transfer_broker_.get_sense_vlan_2()));
+        if class_transfer_broker_.get_num_circuits == 2: cmd = os.popen(str('sh noted/sense-o/sense-cancel.sh ' + class_transfer_broker_.get_sense_uuid_2() + ' ' + class_transfer_broker_.get_sense_vlan_2()));
     send_email(params, message)
     if 'src_rcsite' in threading.current_thread().name: filename = params.get('FILENAME PARAMETERS', 'filename_transfers_src')
     else: filename = params.get('FILENAME PARAMETERS', 'filename_transfers_dst')
